| Title: | Gene Expression displaYer of SummarizedExperiment in R |
|---|---|
| Description: | Lightweight Expression displaYer (plotter / viewer) of SummarizedExperiment object in R. This package provides a quick and easy Shiny-based GUI to empower a user to use a SummarizedExperiment object to view |
| Authors: | David McGaughey [aut, cre] (ORCID: <https://orcid.org/0000-0002-9224-2888>) |
| Maintainer: | David McGaughey <[email protected]> |
| License: | CC0 |
| Version: | 1.5.0 |
| Built: | 2026-05-30 08:16:10 UTC |
| Source: | https://github.com/bioc/geyser |
Functions to handle loading, saving, and applying configurations
Apply a configuration to the Shiny session
apply_config(config, session, rv)apply_config(config, session, rv)
config |
List containing configuration parameters |
session |
Shiny session object |
rv |
reactiveValues object containing app state |
Apply embedded config from SummarizedExperiment if present
apply_embedded_config(rse, session, rv)apply_embedded_config(rse, session, rv)
rse |
SummarizedExperiment object |
session |
Shiny session object |
rv |
reactiveValues object |
Apply pending group filters to dynamic UI
apply_pending_group_filters(rv, input, session)apply_pending_group_filters(rv, input, session)
rv |
reactiveValues object |
input |
Shiny input object |
session |
Shiny session object |
Apply pending sample filter to table
apply_pending_sample_filter(rv, input)apply_pending_sample_filter(rv, input)
rv |
reactiveValues object |
input |
Shiny input object |
Create configuration download handler
create_config_download_handler(input)create_config_download_handler(input)
input |
Shiny input object |
Extract geyser config from SummarizedExperiment metadata
extract_config_from_metadata(rse)extract_config_from_metadata(rse)
rse |
SummarizedExperiment object |
List containing config or NULL if not found
Run shiny app to use SummarizedExperiment object to display genomics data
geyser( rse = NULL, app_name = "geyser", primary_color = "#3A5836", secondary_color = "#d5673e", computer_data_dir = NULL )geyser( rse = NULL, app_name = "geyser", primary_color = "#3A5836", secondary_color = "#d5673e", computer_data_dir = NULL )
rse |
SummarizedExperiment object. If NULL (the default), the app will start with a file upload screen. |
app_name |
Title name that goes on the top left of the Shiny app |
primary_color |
The title bar color |
secondary_color |
The plot action button color |
computer_data_dir |
Optional folder path to existing SummarizedExperiment RDS files. |
A Shiny app object
if (interactive()) { load(system.file('extdata/tiny_rse.Rdata', package = 'geyser')) geyser(tiny_rse, "Test RSE") }if (interactive()) { load(system.file('extdata/tiny_rse.Rdata', package = 'geyser')) geyser(tiny_rse, "Test RSE") }
Setup configuration preset observer
setup_config_preset_observer(input, session, rv)setup_config_preset_observer(input, session, rv)
input |
Shiny input object |
session |
Shiny session object |
rv |
reactiveValues object |
Setup configuration upload observer
setup_config_upload_observer(input, session, rv)setup_config_upload_observer(input, session, rv)
input |
Shiny input object |
session |
Shiny session object |
rv |
reactiveValues object |